#include <avr/io.h>
#include <avr/interrupt.h>
#include <stdbool.h>

#include "Buttons.h"
#include "HAL.h"
#include "Printf.h"

static bool buttonState[2];
static unsigned char buttonCounter[2];
static bool buttonInterrupt[2];

static void processButtonState(unsigned char aId, bool aPressed) {
	if (aPressed != buttonState[aId]) {
		/* Different from internal state, looking at the state necessary */
		if (aPressed) {
			if (++buttonCounter[aId] == BUTTON_UPPER_LIMIT) {
				buttonState[aId] = true;
				buttonInterrupt[aId] = true;
			}
		} else {
			if (--buttonCounter[aId] == 0) {
				buttonState[aId] = false;
			}
		}
	}
}

/* Executes all 4.4ms, i.e. 225 Hz */
ISR(TIMER0_OVF_vect) {
	processButtonState(0, Switch1_IsActive());
	processButtonState(1, Switch2_IsActive());
}

void buttonClearIRQ(void) {
	unsigned char i;
	for (i = 0; i < 2; i++) {
		buttonInterrupt[i] = false;
	}
}

bool buttonGet(unsigned char aId) {
	bool result = buttonInterrupt[aId];
	buttonInterrupt[aId] = false;
	return result;
}

void initButtons(void) {
	TCCR0 = _BV(CS02);
	TIMSK |= _BV(TOIE0);
}
