#include <avr/pgmspace.h>
#include <util/crc16.h>
#include <avr/eeprom.h>

#include "Configuration.h"

static struct config defaultConfiguration PROGMEM = {
	.pedalMinValue = 35,
	.pedalMaxValue = 1000,
	.potMinValue = 0,
	.potMaxValue = 737,
	.maxMotion = 75,
	.pwmSource = PWMSOURCE_PEDAL,
};

static void configurationDefault(struct config *aConfiguration) {
	memcpy_P(aConfiguration, &defaultConfiguration, sizeof(struct config));
}

void eepromWrite(uint16_t aOffset, unsigned char aByte) {
	eeprom_write_byte((uint8_t*)aOffset, aByte);
}

unsigned char eepromRead(uint16_t aOffset) {
	return eeprom_read_byte((uint8_t*)aOffset);
}

static uint16_t configurationCRC(const struct config *aConfiguration) {
	unsigned char i;
	uint16_t crcValue;
	const unsigned char *data = (const unsigned char*)aConfiguration;
	crcValue = 0xffff;
	for (i = 0; i < sizeof(struct config); i++) {
		crcValue = _crc16_update(crcValue, data[i]);
	}
	return crcValue;
}

static uint16_t configurationReadCRC(void) {
	return (eepromRead(sizeof(struct config) + 0) << 0) | (eepromRead(sizeof(struct config) + 1) << 8);
}

static void configurationWriteCRC(uint16_t aCRC) {
	eepromWrite(sizeof(struct config) + 0, (aCRC & 0x00ff) >> 0);
	eepromWrite(sizeof(struct config) + 1, (aCRC & 0xff00) >> 8);
}

void configurationGet(struct config *aConfiguration) {
	unsigned char i;
	for (i = 0; i < sizeof(struct config); i++) {
		((unsigned char*)aConfiguration)[i] = eepromRead(i);
	}
}

void configurationSet(const struct config *aConfiguration) {
	unsigned char i;
	for (i = 0; i < sizeof(struct config); i++) {
		eepromWrite(i, ((unsigned char*)aConfiguration)[i]);
	}
	configurationWriteCRC(configurationCRC(aConfiguration));
}

void configurationInit(void) {
	struct config c;
	configurationGet(&c);
	if (configurationCRC(&c) != configurationReadCRC()) {
		/* Stored CRC in EEPROM was invalid! */
		configurationDefault(&c);
		configurationSet(&c);
	}
}

