#ifndef __LCD_H__
#define __LCD_H__

#include <stdio.h>
#include <avr/pgmspace.h>

#define LCD_DISPLAY_COUNT					1
#define LCD_PRINTF

#ifdef LCD_PRINTF
extern FILE lcdout;
#define lcdprintf(x, y, text, ...)			{ lcdGotoXY(x, y); fprintf_P(&lcdout, PSTR(text), ##__VA_ARGS__); }
#endif

#define LCD_ARROW_RIGHT						"\x7e"
#define LCD_ARROW_LEFT						"\x7f"
#define LCD_DEGREE							"\xdf"

#define LCD_GREEK_ALPHA						"\xe0"
#define LCD_GREEK_BETA						"\xe2"
#define LCD_GREEK_EPSILON					"\xe3"
#define LCD_GREEK_MU						"\xe4"
#define LCD_GREEK_SIGMA						"\xe5"
#define LCD_GREEK_PI						"\xf7"
#define LCD_GREEK_THETA						"\xf2"
#define LCD_GREEK_OMEGA						"\xf4"

#define LCD_AUML							"\xe1"
#define LCD_OUML							"\xef"
#define LCD_UUML							"\xf5"
#define LCD_SSUML							"\xe2"

struct LCDDisplayState {
	unsigned char checkBusy;
	unsigned char lastDisplay;
};

#define REGISTER_CTRL						0
#define REGISTER_DATA						1

#define ENTRYMODESET_DECREMENT				0
#define ENTRYMODESET_INCREMENT				1
#define ENTRYMODESET_NOMOVE					0
#define ENTRYMODESET_MOVE					1

#define DISPLAYONOFF_OFF					0
#define DISPLAYONOFF_ON						1
#define DISPLAYONOFF_NOUNDERLINECURSOR		0
#define DISPLAYONOFF_UNDERLINECURSOR		1
#define DISPLAYONOFF_NOBLINKINGCURSOR		0
#define DISPLAYONOFF_BLINKINGCURSOR			1

#define SYSTEMSET_4BIT						0
#define SYSTEMSET_8BIT						1
#define SYSTEMSET_SINGLELINE				0
#define SYSTEMSET_MULTILINE					1
#define SYSTEMSET_5_TO_7_DRAWINGBOX			0
#define SYSTEMSET_5_TO_10_DRAWINGBOX		1
#define SYSTEMSET_INVERTER_OFF				0
#define SYSTEMSET_INVERTER_ON				1

/*************** AUTO GENERATED SECTION FOLLOWS ***************/
void lcdClearDisplay(unsigned char aDisplayNumber);
void lcdInit(void);
void lcdGotoXY(unsigned char aX, unsigned char aY);
void lcdPrintChar(char aCharacter);
void lcdPrintCharXY(unsigned char aX, unsigned char aY, char aCharacter);
void lcdPrintString_P(PGM_P aPgmPtr);
void lcdPrintStringXY_P(unsigned char aX, unsigned char aY, PGM_P aPgmPtr);
/***************  AUTO GENERATED SECTION ENDS   ***************/

#endif
