#include <stdbool.h>

#include "LCD.h"
#include "Delay.h"
#include "Controller.h"
#include "Information.h"

void menuSplashScreen(void) {
	lcdClearDisplay(0);
	lcdprintf(1, 0, "Joe's Elspira");
	lcdprintf(1, 1, "\x5e\x5e\x5e\x5e\x5e\x5e\x5e\x5e\x5e\x5e\x5e\x5e\x5e");
	delayMillis(1500);
	lcdClearDisplay(0);

	lcdprintf(3, 0, "F" LCD_UUML "r Julaia");
	lcdprintf(3, 1, "\x5e\x5e\x5e\x5e\x5e\x5e\x5e\x5e\x5e\x5e");
	delayMillis(1500);
	lcdClearDisplay(0);
}

// [  Start  !  34°C]
// [100%/100%   61°C]
void updateScreenMain(bool aFullRedraw) {
	if (aFullRedraw) {
		lcdClearDisplay(0);
		lcdprintf(3, 1, "%%/");
		lcdprintf(8, 1, "%%");
		lcdprintf(14, 0, LCD_DEGREE "C");
		lcdprintf(14, 1, LCD_DEGREE "C");
	}
	if (controllerGetMode() == MODE_STOPPED) {
		lcdprintf(2, 0, "STOP ");
	} else {
		lcdprintf(2, 0, "Start");
	}
	lcdprintf(0, 1, "%3d", controllerGetCurPercent());
	lcdprintf(5, 1, "%3d", controllerGetMaxPercent());
	lcdprintf(9, 0, "%c %3d", (controllerGetSource() == PWMSOURCE_PEDAL) ? 'F' : 'D', controllerGetMotorTemperature());
	lcdprintf(11, 1, "%3d", controllerGetMosfetTemperature());
}

// [ Fußpedal       ]
// [ kalibrieren?   ]
void updateScreenSelectCalPedal(bool aFullRedraw) {
	if (aFullRedraw) {
		lcdClearDisplay(0);
		lcdprintf(1, 0, "Fu" LCD_SSUML "pedal");
		lcdprintf(1, 1, "kalibrieren?");
	}
}


// [ Drehregler     ]
// [ kalibrieren?   ]
void updateScreenSelectCalPot(bool aFullRedraw) {
	if (aFullRedraw) {
		lcdClearDisplay(0);
		lcdprintf(1, 0, "Drehregler");
		lcdprintf(1, 1, "kalibrieren?");
	}
}


// [ Max. Drehzahl  ]
// [ (momentan 72%)?]
void updateScreenSelectMax(bool aFullRedraw) {
	if (aFullRedraw) {
		lcdClearDisplay(0);
		lcdprintf(1, 0, "Max. Drehzahl");
		lcdprintf(1, 1, "(momentan %3d%%)?", controllerGetMaxPercent());
	}
}


// [ Eingabegerät:  ]
// [   Fußpedal     ]

// [ Eingabegerät:  ]
// [   Drehregler   ]
void updateScreenSelectSource(bool aFullRedraw) {
	if (aFullRedraw) {
		lcdClearDisplay(0);
		lcdprintf(1, 0, "Eingabeger" LCD_AUML "t:");
	}

	if (controllerGetSource() == PWMSOURCE_PEDAL) {
		lcdprintf(3, 1, "Fu" LCD_SSUML "pedal  ");
	} else {
		lcdprintf(3, 1, "Drehregler");
	}
}


// [Fußpedal bewegen]
// [   123 - 4994   ]
void updateScreenCalPedal(bool aFullRedraw) {
	if (aFullRedraw) {
		lcdClearDisplay(0);
		lcdprintf(0, 0, "Fu" LCD_SSUML "pedal bewegen");
		lcdprintf(7, 1, "-");
	}
	lcdprintf(2, 1, "%4d", controllerGetCalibrationLow());
	lcdprintf(9, 1, "%4d", controllerGetCalibrationHigh());
}


// [Regler bewegen  ]
// [   123 - 4994   ]
void updateScreenCalPot(bool aFullRedraw) {
	if (aFullRedraw) {
		lcdClearDisplay(0);
		lcdprintf(0, 0, "Regler bewegen");
		lcdprintf(7, 1, "-");
	}
	lcdprintf(2, 1, "%4d", controllerGetCalibrationLow());
	lcdprintf(9, 1, "%4d", controllerGetCalibrationHigh());
}

// [ Max. Drehzahl  ]
// [     72%        ]
void updateScreenMaxLeft(bool aFullRedraw) {
	if (aFullRedraw) {
		lcdClearDisplay(0);
		lcdprintf(1, 0, "Max. Drehzahl");
		lcdprintf(7, 1, "%%");
	}
	lcdprintf(4, 1, "%3d", controllerGetCalibrationValue());
}


// [ Informationen  ]
// [ v0.3  SVN 1234 ]
void updateScreenInfos(bool aFullRedraw) {
	if (aFullRedraw) {
		lcdClearDisplay(0);
		lcdprintf(1, 0, "Informationen");
		lcdprintf(1, 1, "v" VERSION_INFORMATION);
		lcdprintf(7, 1, "SVN " SVN_REVISION);
	}
}

