#include <avr/io.h>
#include <avr/pgmspace.h>

#include "NTC.h"

static unsigned char ntcLookupTable[] PROGMEM = { 255, 122, 99, 86, 77, 71, 65, 61, 57, 53, 50, 47, 45, 42, 40, 38, 36, 34, 32, 30, 29, 27, 26, 24, 22, 21, 20, 18, 17, 15, 14, 13 };

static unsigned char ntcLookupTableGet(unsigned char aIndex) {
	return pgm_read_byte(ntcLookupTable + aIndex);
}

unsigned char adcValueToTemperature(uint16_t aADCValue) {
	unsigned char entry, modul;
	unsigned char temperature;

	entry = aADCValue / NTC_LOOKUP_TABLE_SIZE;
	modul = aADCValue % NTC_LOOKUP_TABLE_SIZE;
	
	if (entry < (NTC_LOOKUP_TABLE_SIZE - 1)) {
		uint16_t approximation;
		unsigned char value, nextValue;
		unsigned char antiModul = NTC_LOOKUP_TABLE_SIZE - 1 - modul;
		value = ntcLookupTableGet(entry);
		nextValue = ntcLookupTableGet(entry + 1);
		approximation = (value * antiModul) + (nextValue * modul);
		temperature = approximation / (NTC_LOOKUP_TABLE_SIZE - 1);
	} else {
		/* Last entry, no more lookup possible */
		temperature = ntcLookupTableGet(entry);
	}

	return temperature;
}
