#include <stdio.h>
#include <avr/interrupt.h>
#include <avr/io.h>

#include "RS232.h"
#include "HAL.h"

static void initRs232Stdout(void) {
	static FILE uartStdout = FDEV_SETUP_STREAM(rs232PutChar, NULL, _FDEV_SETUP_WRITE);
	stdout = &uartStdout;
}

int rs232PutChar(char aChar, FILE *aStream) {
	rs232TransmitChar(aChar);
	return 1;
}

void rs232TransmitChar(unsigned char aChar) {
	while (!(UCSRA & _BV(UDRE)));		/* Wait until data register empty */
	UDR = aChar;
}

unsigned char rs232ReceiveChar(void) {
	while (!(UCSRA & _BV(RXC)));		/* Wait for reception of byte */
	return UDR;
}

int16_t rs232ReceiveCharTimeout(uint16_t aTimeout) {
	while ((!(UCSRA & _BV(RXC))) && (--aTimeout != 0));	/* Wait for reception of byte or timeout */
	if (aTimeout == 0) return -1;
	return UDR;
}
	
void initRs232(void) {
	UBRRL = 7;								/* 125200 Baud @ 14.7456 MHz */
	UCSRB = _BV(TXEN) | _BV(RXEN);			/* Enable transmitter and receiver */
	initRs232Stdout();
}

